/*----------------------------------------------------------------------------
*         ATMEL Microcontroller Software Support  -  ROUSSET  -
*----------------------------------------------------------------------------
* The software is delivered "AS IS" without warranty or condition of any
* kind, either express, implied or statutory. This includes without
* limitation any warranty or condition with respect to merchantability or
* fitness for any particular purpose, or against the infringements of
* intellectual property rights of others.
*----------------------------------------------------------------------------
* File Name           : Board.h
* Object              : AT91SAM7S Evaluation Board Features Definition File.
*
* Creation            : JPP   16/Jun/2004
* V 1.0 21/Feb/05 JPP : Define __ramfunc
* V 1.1 21/Feb/05 JPP : add Lib definition
* V 1.2 22/Feb/05 JPP : Add DBGU inline definition
*----------------------------------------------------------------------------
*/
#ifndef Board_h
#define Board_h

#include "AT91SAM7S128.h"
#define __inline extern inline
#include "lib_AT91SAM7S128.h"

//* inline definition

#define __ramfunc

#define AT91C_US_ASYNC_MODE ( AT91C_US_USMODE_NORMAL + AT91C_US_NBSTOP_1_BIT + AT91C_US_PAR_NONE + AT91C_US_CHRL_8_BITS + AT91C_US_CLKS_CLOCK )

#define true	-1
#define false	0

/*-------------------------------*/
/* SAM7Board Memories Definition */
/*-------------------------------*/
// The AT91SAM128 embeds a 32-Kbyte SRAM bank, and 128 K-Byte Flash

#define  INT_SARM           0x00200000
#define  INT_SARM_REMAP	    0x00000000

#define  INT_FLASH          0x00000000
#define  INT_FLASH_REMAP    0x01000000

#define  FLASH_PAGE_NB	    512
#define  FLASH_PAGE_LOCK    32
#define  FLASH_PAGE_SIZE    128

/*-----------------*/
/* Ports definition*/
/*-----------------*/

/* Based on Matrix */
/*    ARM ECIO     */

#define PORTA0 			( 1<<24 )
#define PORTA1			( 1<<26 )
#define PORTA2			( 1<<11 )
#define PORTA3			( 1<<10 )
#define PORTA4			( 1<<9 )
#define PORTA5			( 1<<8 )
#define PORTA6			( 1<<6 ) /* TX0 */
#define PORTA7			( 1<<5 ) /* RX0 */

#define PORTA (PORTA0|PORTA1|PORTA2|PORTA3|PORTA4|PORTA5|PORTA6|PORTA7)

#define PORTB0			( 1<<23 )
#define PORTB1			( 1<<20 ) /* AD3 */
#define PORTB2			( 1<<31 )
#define PORTB3			( 1<<15 )
#define PORTB4			( 1<<14 ) /* SPI */
#define PORTB5			( 1<<13 ) /* SPI */
#define PORTB6			( 1<<25 )
#define PORTB7			( 1<<12 ) /* SPI */

#define PORTB (PORTB0|PORTB1|PORTB2|PORTB3|PORTB4|PORTB5|PORTB6|PORTB7)

#define PORTC0			( 1<<17 ) /* AD0 */
#define PORTC1			( 1<<18 ) /* AD1 */
#define PORTC2			( 1<<19 ) /* AD2 */
#define PORTC3			( 1<<7 )
#define PORTC4			( 0 )	  /* N/A */
#define PORTC5			( 0 )	  /* N/A */
#define PORTC6			( 1<<22 ) /* TX1 */
#define PORTC7			( 1<<21 ) /* RX1 */

#define PORTC (PORTC0|PORTC1|PORTC2|PORTC3|PORTC4|PORTC5|PORTC6|PORTC7)

#define PORTD0			( 1<<4 ) /* I2C */
#define PORTD1			( 1<<27 ) 
#define PORTD2			( 1<<28 ) 
#define PORTD3			( 1<<29 ) 
#define PORTD4			( 1<<3 ) /* I2C */
#define PORTD5			( 1<<2 ) /* PWM */
#define PORTD6			( 1<<1 ) /* PWM */
#define PORTD7			( 1<<0 ) /* PWM */

#define PORTD (PORTD0|PORTD1|PORTD2|PORTD3|PORTD4|PORTD5|PORTD6|PORTD7)

/*--------------*/
/* Master Clock */
/*--------------*/

#define MCKKHz          (MCK/1000) //
#define MCKMHz		((MCKKHz+500)/1000) //

/* This line tells the compiler that all functions preceeded */
/* by 'RAMFUNC' should be run from RAM and not Flash, */
/* meaning that we can use them to alter flash */
#define RAMFUNC __attribute__ ((section (".ramfunc")/*, long_call*/))

#endif /* Board_h */
